pub unsafe extern "C" fn ts_language_state_count(
self_: *const TSLanguage,
) -> u32Expand description
Get the number of valid states in this language.
pub unsafe extern "C" fn ts_language_state_count(
self_: *const TSLanguage,
) -> u32Get the number of valid states in this language.