pub unsafe extern "C" fn ts_language_symbol_count(
self_: *const TSLanguage,
) -> u32Expand description
Get the number of distinct node types in the language.
pub unsafe extern "C" fn ts_language_symbol_count(
self_: *const TSLanguage,
) -> u32Get the number of distinct node types in the language.