pub unsafe extern "C" fn ts_language_symbol_type(
self_: *const TSLanguage,
symbol: TSSymbol,
) -> TSSymbolTypeExpand description
Check whether the given node type id belongs to named nodes, anonymous nodes, or a hidden nodes.
See also ts_node_is_named. Hidden nodes are never returned from the API.