pub unsafe extern "C" fn ts_lookahead_iterator_next(
self_: *mut TSLookaheadIterator,
) -> boolExpand description
Advance the lookahead iterator to the next symbol.
This returns true if there is a new symbol and false otherwise.
pub unsafe extern "C" fn ts_lookahead_iterator_next(
self_: *mut TSLookaheadIterator,
) -> boolAdvance the lookahead iterator to the next symbol.
This returns true if there is a new symbol and false otherwise.