pub unsafe extern "C" fn ts_node_edit(
self_: *mut TSNode,
edit: *const TSInputEdit,
)Expand description
Edit the node to keep it in-sync with source code that has been edited.
This function is only rarely needed. When you edit a syntax tree with the
ts_tree_edit function, all of the nodes that you retrieve from the tree
afterward will already reflect the edit. You only need to use ts_node_edit
when you have a TSNode instance that you want to keep and continue to use
after an edit.
The edit’s start_byte must be less than or equal to its old_end_byte,
and its start_point must be less than or equal to its old_end_point.