tree_sitter::ffi

Function ts_point_edit

pub unsafe extern "C" fn ts_point_edit(
    point: *mut TSPoint,
    point_byte: *mut u32,
    edit: *const TSInputEdit,
)
Edit a point to keep it in-sync with source code that has been edited.

This function updates a single point’s byte offset and row/column position based on an edit operation. This is useful for editing points without requiring a tree or node instance.

The edit’s start_byte must be less than or equal to its old_end_byte, and its start_point must be less than or equal to its old_end_point.