pub unsafe extern "C" fn ts_query_cursor_delete(
self_: *mut TSQueryCursor,
)Expand description
Delete a query cursor, freeing all of the memory that it used.
pub unsafe extern "C" fn ts_query_cursor_delete(
self_: *mut TSQueryCursor,
)Delete a query cursor, freeing all of the memory that it used.