pub unsafe extern "C" fn ts_tree_cursor_goto_first_child(
self_: *mut TSTreeCursor,
) -> boolExpand description
Move the cursor to the first child of its current node.
This returns true if the cursor successfully moved, and returns false
if there were no children.