tree_sitter::ffi

Function ts_tree_cursor_goto_first_child_for_byte

pub unsafe extern "C" fn ts_tree_cursor_goto_first_child_for_byte(
    self_: *mut TSTreeCursor,
    goal_byte: u32,
) -> i64
Move the cursor to the first child of its current node that contains or starts after the given byte offset or point.

This returns the index of the child node if one was found, and returns -1 if no such child was found.