pub unsafe extern "C" fn ts_tree_edit(
self_: *mut TSTree,
edit: *const TSInputEdit,
)Expand description
Edit the syntax tree to keep it in sync with source code that has been edited.
You must describe the edit both in terms of byte offsets and in terms of (row, column) coordinates.
The edit’s start_byte must be less than or equal to its old_end_byte,
and its start_point must be less than or equal to its old_end_point.