pub unsafe extern "C" fn ts_wasm_store_delete(arg1: *mut TSWasmStore)Expand description
Free the memory associated with the given Wasm store.
pub unsafe extern "C" fn ts_wasm_store_delete(arg1: *mut TSWasmStore)Free the memory associated with the given Wasm store.