pub unsafe extern "C" fn ts_wasm_store_language_count(
arg1: *const TSWasmStore,
) -> usizeExpand description
Get the number of languages instantiated in the given Wasm store.
pub unsafe extern "C" fn ts_wasm_store_language_count(
arg1: *const TSWasmStore,
) -> usizeGet the number of languages instantiated in the given Wasm store.