pub trait Decode { // Required method fn decode(bytes: &[u8]) -> (i32, u32); }
A callback that decodes the next code point from the input slice. It should return the code point, and how many bytes were decoded.
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".