pub unsafe extern "C" fn ts_range_edit(
range: *mut TSRange,
edit: *const TSInputEdit,
)Expand description
Edit a range to keep it in-sync with source code that has been edited.
This function updates a range’s start and end positions based on an edit operation. This is useful for editing ranges without requiring a tree or node instance.
The edit’s start_byte must be less than or equal to its old_end_byte,
and its start_point must be less than or equal to its old_end_point.