Struct tree_sitter::Language [−][src]
#[repr(transparent)]pub struct Language(_);
An opaque object that defines how to parse a particular language. The code for each
Language is generated by the Tree-sitter CLI.
Implementations
impl Language[src]
impl Language[src]pub fn version(&self) -> usize[src]
pub fn version(&self) -> usize[src]Get the ABI version number that indicates which version of the Tree-sitter CLI
that was used to generate this Language.
pub fn node_kind_count(&self) -> usize[src]
pub fn node_kind_count(&self) -> usize[src]Get the number of distinct node types in this language.
pub fn node_kind_for_id(&self, id: u16) -> Option<&'static str>[src]
pub fn node_kind_for_id(&self, id: u16) -> Option<&'static str>[src]Get the name of the node kind for the given numerical id.
pub fn id_for_node_kind(&self, kind: &str, named: bool) -> u16[src]
pub fn id_for_node_kind(&self, kind: &str, named: bool) -> u16[src]Get the numeric id for the given node kind.
pub fn node_kind_is_named(&self, id: u16) -> bool[src]
pub fn node_kind_is_named(&self, id: u16) -> bool[src]Check if the node type for the given numerical id is named (as opposed to an anonymous node type).
pub fn node_kind_is_visible(&self, id: u16) -> bool[src]
pub fn field_count(&self) -> usize[src]
pub fn field_count(&self) -> usize[src]Get the number of distinct field names in this language.
pub fn field_name_for_id(&self, field_id: u16) -> Option<&'static str>[src]
pub fn field_name_for_id(&self, field_id: u16) -> Option<&'static str>[src]Get the field names for the given numerical id.